Installation
============

Installing with ``pip``
-----------------------

The package can be installed from the official Python package index using ``pip``.

.. code-block:: bash

    $ pip install manen

This command will install the `latest version <https://pypi.org/project/manen/>`_
available on PyPI.

Installing from the Git repository
----------------------------------

You can also install the package directly from the Git repository:

.. code-block:: bash

    $ pip install git+https://github.com/kodaho/manen.git@main

This command will install the package from the latest commit on the ``main`` branch.

To install the package from a specific branch or tag (e.g. ``latest`` which is the latest version
published on PyPI), you can use:

.. code-block:: bash

    $ pip install git+https://github.com/kodaho/manen.git@latest

.. warning::

    The ``main`` branch is a development branch and may contain unstable code. If you want to
    install the package for development purposes, you can check the :ref:`Contributing` page.
